@@ -1,16 +1,19 @@
 mod findpackage;
 pub mod treehelper;
-use std::collections::HashMap;
 use std::path::PathBuf;
 use std::sync::LazyLock;
+use std::{collections::HashMap, sync::Mutex};
 
 use serde::{Deserialize, Serialize};
 
-use crate::Url;
+use tower_lsp::lsp_types::Uri;
 
 static PLACE_HODER_REGEX: LazyLock<regex::Regex> =
     LazyLock::new(|| regex::Regex::new(r"\$\{(\w+)\}").unwrap());
 
+static PLACE_ENV_HODER_REGEX: LazyLock<regex::Regex> =
+    LazyLock::new(|| regex::Regex::new(r"\$ENV\{(\w+)\}").unwrap());
+
 #[derive(Deserialize, Debug, Serialize, Clone, PartialEq, Eq)]
 pub enum PackageType {
     Dir,
@@ -44,7 +47,7 @@ impl std::fmt::Display for CMakePackageFrom {
 pub struct CMakePackage {
     pub name: String,
     pub packagetype: PackageType,
-    pub location: Url,
+    pub location: Uri,
     pub version: Option<String>,
     pub tojump: Vec<PathBuf>,
     pub from: CMakePackageFrom,
@@ -147,6 +150,9 @@ pub fn remove_quotation(origin: &str) -> &str {
 }
 
 pub fn replace_placeholders(template: &str) -> Option<String> {
+    if template.contains("$ENV{") {
+        return replace_placeholders_with_env_map(template);
+    }
     if !template.contains("${") {
         return Some(template.to_string());
     }
@@ -154,6 +160,31 @@ pub fn replace_placeholders(template: &str) -> Option<String> {
     replace_placeholders_with_hashmap(template, &values)
 }
 
+static CACHE_ENV_DATA: LazyLock<Mutex<HashMap<String, String>>> =
+    LazyLock::new(|| Mutex::new(HashMap::new()));
+
+fn replace_placeholders_with_env_map(template: &str) -> Option<String> {
+    let mut result = template.to_string();
+
+    let mut cache = CACHE_ENV_DATA.lock().unwrap();
+    for caps in PLACE_ENV_HODER_REGEX.captures_iter(template) {
+        let key = &caps[1];
+        match cache.get(key) {
+            Some(value) => {
+                result = result.replace(&caps[0], value);
+            }
+            None => {
+                let Ok(value) = std::env::var(key) else {
+                    return None;
+                };
+                result = result.replace(&caps[0], &value);
+                cache.insert(key.to_string(), value);
+            }
+        }
+    }
+    Some(result)
+}
+
 fn replace_placeholders_with_hashmap(
     template: &str,
     values: &HashMap<String, String>,
@@ -172,6 +203,17 @@ fn replace_placeholders_with_hashmap(
     Some(result)
 }
 
+#[test]
+fn env_arg_test() {
+    unsafe {
+        std::env::set_var("TempDir", "/tmp");
+    }
+    assert_eq!(
+        "/tmp/wezterm",
+        replace_placeholders("$ENV{TempDir}/wezterm").unwrap()
+    )
+}
+
 #[test]
 fn brank_remove_test() {
     let testa = "\"abc\"";
